============
lib_dzne_tsv
============

Overview
--------

Libary for handling tsv-data.

Installation
------------

To install lib_dzne_tsv, you can use `pip`. Open your terminal and run:

.. code-block:: bash

    pip install lib_dzne_tsv

License
-------

This project is licensed under the MIT License.

Credits
-------
- Author: Johannes Programming
- Email: johannes-programming@posteo.org

Thank you for using lib_dzne_tsv!